@@ -20,8 +20,9 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
             raise LookupError("Model not found. " + str(response))
     if bson.ObjectId.is_valid(model):
         return model
-
+    print("Saving model locally.")
     file_path = save_model(model, library)
+    print("Model saved locally.")
     with open(file_path, "rb") as file:
         hash = hashlib.md5(file.read()).hexdigest()
         if model_label == "":
