@@ -56,9 +56,13 @@ def save_model(model, library: str):
 def save_data(data):
     file = TemporaryFile()
     if isinstance(data, (tuple, list)):
+        if not all([isinstance(x, np.ndarray) for x in data]):
+            raise TypeError("Either train or validation data is not in numpy array format.")
         dict_data = {str(i): data[i] for i in range(0, len(data))}
         np.savez_compressed(file, **dict_data)
     else:
+        if not isinstance(data, np.ndarray):
+            raise TypeError("Data is not in numpy array format.")
         np.savez_compressed(file, data)
     file.seek(0)
     return file
